@@ -760,6 +760,7 @@ typedef struct
 	wan_ticks_t	sec_chk_cnt;
 	wan_skb_queue_t	rtp_tap_list;
 	unsigned int	serial_status;
+	unsigned char	global_tdm_irq;
 
 } sdla_xilinx_t;
 
@@ -978,6 +979,8 @@ typedef struct sdla
         void* sdla_tdmv_dummy;
 #endif
 
+	unsigned char wp_debug_chan_seq;
+
 } sdla_t;
 
 /****** Public Functions ****************************************************/
@@ -1053,6 +1056,7 @@ extern struct wanpipe_lapb_register_struct lapb_protocol;
 int wan_snmp_data(sdla_t* card, netdevice_t* dev, int cmd, struct ifreq* ifr);
 
 int wan_capture_trace_packet(sdla_t *card, wan_trace_t* trace_info, netskb_t *skb, char direction);
+int wan_capture_trace_packet_buffer(sdla_t *card, wan_trace_t* trace_info, char *data, int len, char direction);
 int wan_capture_trace_packet_offset(sdla_t *card, wan_trace_t* trace_info, netskb_t *skb, int off,char direction);
 
 #if defined(__LINUX__)
